@@ -3,12 +3,12 @@
 #' Shows the percent contribution and permutation importance of the
 #' environmental variables used to train the model.
 #'
-#' @param model \linkS4class{SDMmodel} or \linkS4class{SDMmodelCV} object
-#' trained using the "Maxent" method.
+#' @param model \code{\linkS4class{SDMmodel}} or \code{\linkS4class{SDMmodelCV}}
+#' object trained using the "Maxent" method.
 #'
-#' @details When an \linkS4class{SDMmodelCV} object is passed to the function,
-#' the output is the average of the variable importance of each model trained
-#' during the cross validation.
+#' @details When an \code{\linkS4class{SDMmodelCV}} object is passed to the
+#' function, the output is the average of the variable importance of each model
+#' trained during the cross validation.
 #'
 #' @return A data frame with the variable importance.
 #' @export
@@ -24,20 +24,16 @@
 #'                     pattern = "grd", full.names = TRUE)
 #' predictors <- raster::stack(files)
 #'
-#' # Prepare presence locations
-#' p_coords <- condor[, 1:2]
-#'
-#' # Prepare background locations
-#' bg_coords <- dismo::randomPoints(predictors, 5000)
+#' # Prepare presence and background locations
+#' p_coords <- virtualSp$presence
+#' bg_coords <- virtualSp$background
 #'
 #' # Create SWD object
-#' presence <- prepareSWD(species = "Vultur gryphus", coords = p_coords,
-#'                        env = predictors, categorical = "biome")
-#' bg <- prepareSWD(species = "Vultur gryphus", coords = bg_coords,
-#'                  env = predictors, categorical = "biome")
+#' data <- prepareSWD(species = "Virtual species", p = p_coords, a = bg_coords,
+#'                    env = predictors, categorical = "biome")
 #'
 #' # Train a Maxent model
-#' model <- train(method = "Maxent", p = presence, a = bg, fc = "l")
+#' model <- train(method = "Maxent", data = data, fc = "l")
 #' maxentVarImp(model)
 #' }
 maxentVarImp <- function(model) {
@@ -49,7 +45,7 @@ maxentVarImp <- function(model) {
     x <- model@model@results
     df <- .fetch_var_imp(x)
   } else {
-    vars <- colnames(model@p@data)
+    vars <- colnames(model@data@data)
     l <- length(model@models)
     pcs <- pis <- matrix(nrow = length(vars), ncol = l)
     for (i in 1:l) {
