@@ -12,13 +12,12 @@
 #' @param test \code{\linkS4class{SWD}} object. Test dataset used to evaluate
 #' the model, not used with aicc and \code{\linkS4class{SDMmodelCV}} objects,
 #' default is \code{NULL}.
-#' @param bg4test Deprecated.
 #' @param pop numeric. Size of the population, default is 5.
 #' @param gen numeric. Number of generations, default is 20.
 #' @param env \code{\link[raster]{stack}} containing the environmental
 #' variables, used only with "aicc", default is \code{NULL}.
 #' @param parallel logical, if \code{TRUE} it uses parallel computation, default
-#' is \code{FALSE}.
+#' is \code{FALSE}. Used only with \code{metric = "aicc"}, see details.
 #' @param keep_best numeric. Percentage of the best models in the population to
 #' be retained during each iteration, expressed as decimal number. Default
 #' is 0.4.
@@ -29,11 +28,15 @@
 #' @param seed numeric. The value used to set the seed to have consistent
 #' results, default is \code{NULL}.
 #'
-#' @details To know which hyperparameters can be tuned you can use the output of
-#' the function \code{\link{get_tunable_args}}. Hyperparameters not included in
-#' the \code{hypers} argument take the value that they have in the passed model.
-#' Parallel computation increases the speed only for large datasets due to the
-#' time necessary to create the cluster. Part of the code is inspired by
+#' @details To know which hyperparameters can be tuned you can use the output
+#' of the function \code{\link{get_tunable_args}}. Hyperparameters not included
+#' in the \code{hypers} argument take the value that they have in the passed
+#' model.
+#' * Parallel computation is used only during the execution of the predict
+#' function, and increases the speed only for large datasets. For small dataset
+#' it may result in a longer execution, due to the time necessary to create the
+#' cluster.
+#' * Part of the code is inspired by
 #' \href{https://blog.coast.ai/lets-evolve-a-neural-network-with-a-geneticalgorithm-code-included-8809bece164}{this post}.
 #'
 #' @return \code{\linkS4class{SDMtune}} object.
@@ -78,15 +81,10 @@
 #' output@models
 #' output@models[[1]]  # Best model
 #' }
-optimizeModel <- function(model, hypers, metric, test = NULL, bg4test = NULL,
-                          pop = 20, gen = 5, env = NULL, parallel = FALSE,
-                          keep_best = 0.4, keep_random = 0.2,
-                          mutation_chance = 0.4, seed = NULL) {
-
-  # TODO remove it next release
-  if (!is.null(bg4test))
-    warning("Argument \"bg4test\" is deprecated and ignored, it will be ",
-            "removed in the next release.")
+optimizeModel <- function(model, hypers, metric, test = NULL, pop = 20, gen = 5,
+                          env = NULL, parallel = FALSE, keep_best = 0.4,
+                          keep_random = 0.2, mutation_chance = 0.4,
+                          seed = NULL) {
 
   metric <- match.arg(metric, choices = c("auc", "tss", "aicc"))
 
