@@ -13,20 +13,22 @@
 #' @param test \code{\linkS4class{SWD}} object. Test dataset used to evaluate
 #' the model, not used with aicc and \code{\linkS4class{SDMmodelCV}} objects,
 #' default is \code{NULL}.
-#' @param bg4test Deprecated.
 #' @param pop numeric. Size of the population, default is 20.
 #' @param env \code{\link[raster]{stack}} containing the environmental
 #' variables, used only with "aicc", default is \code{NULL}.
 #' @param parallel logical, if \code{TRUE} it uses parallel computation, default
-#' is \code{FALSE}.
+#' is \code{FALSE}. Used only with \code{metric = "aicc"}, see details.
 #' @param seed numeric. The value used to set the seed to have consistent
 #' results, default is \code{NULL}.
 #'
-#' @details To know which hyperparameters can be tuned you can use the output of
-#' the function \code{\link{get_tunable_args}}. Hyperparameters not included in
-#' the \code{hypers} argument take the value that they have in the passed model.
-#' Parallel computation increases the speed only for large datasets due to the
-#' time necessary to create the cluster.
+#' @details * To know which hyperparameters can be tuned you can use the output
+#' of the function \code{\link{get_tunable_args}}. Hyperparameters not included
+#' in the \code{hypers} argument take the value that they have in the passed
+#' model.
+#' * Parallel computation is used only during the execution of the predict
+#' function, and increases the speed only for large datasets. For small dataset
+#' it may result in a longer execution, due to the time necessary to create the
+#' cluster.
 #'
 #' @return \code{\linkS4class{SDMtune}} object.
 #' @export
@@ -67,13 +69,8 @@
 #' # Order rusults by highest test AUC
 #' output@results[order(-output@results$test_AUC), ]
 #' }
-randomSearch <- function(model, hypers, metric, test = NULL, bg4test = NULL,
-                         pop = 20, env = NULL, parallel = FALSE, seed = NULL) {
-
-  # TODO remove it next release
-  if (!is.null(bg4test))
-    warning("Argument \"bg4test\" is deprecated and ignored, it will be ",
-            "removed in the next release.")
+randomSearch <- function(model, hypers, metric, test = NULL, pop = 20,
+                         env = NULL, parallel = FALSE, seed = NULL) {
 
   metric <- match.arg(metric, choices = c("auc", "tss", "aicc"))
 
