@@ -1,4 +1,5 @@
 skip_on_cran()
+skip_on_appveyor()
 
 data <- SDMtune:::t
 files <- list.files(path = file.path(system.file(package = "dismo"), "ex"),
@@ -40,10 +41,8 @@ test_that("gridSearch produces the expected output with AICc", {
 
 test_that("gridSearch produces the expected output with cross validation", {
   h <- list(fc = c("l", "q"), reg = c(1, 2))
-  expect_warning(o <- gridSearch(m_cv, hypers = h, metric = "auc", test = data,
-                  save_models = FALSE, seed = 25),
-                  "Argument \"seed\" is deprecated and ignored")
-  expect_s4_class(o, "SDMtune")
+  o <- gridSearch(m_cv, hypers = h, metric = "auc", test = data,
+                  save_models = FALSE)
   expect_s3_class(o@results, "data.frame")
   expect_named(o@results, c("fc", "reg", "train_AUC", "test_AUC", "diff_AUC"))
   expect_length(o@models, 1)
